@@ -250,8 +250,6 @@ static void lm87_vid(struct i2c_client *client, int operation,
 static void lm87_vrm(struct i2c_client *client, int operation,
 			int ctl_name, int *nrels_mag, long *results);
 
-static int lm87_id = 0;
-
 static struct i2c_driver LM87_driver = {
 	.name		= "LM87 sensor driver",
 	.id		= I2C_DRIVERID_LM87,
@@ -271,9 +269,9 @@ static struct i2c_driver LM87_driver = {
 #define LM87_SYSCTL_AIN2       1007
 #define LM87_SYSCTL_FAN1       1102
 #define LM87_SYSCTL_FAN2       1103
-#define LM87_SYSCTL_TEMP1      1250 /* Degrees Celcius * 10 */
-#define LM87_SYSCTL_TEMP2      1251 /* Degrees Celcius * 10 */
-#define LM87_SYSCTL_TEMP3      1252 /* Degrees Celcius * 10 */
+#define LM87_SYSCTL_TEMP1      1250 /* Degrees Celsius * 10 */
+#define LM87_SYSCTL_TEMP2      1251 /* Degrees Celsius * 10 */
+#define LM87_SYSCTL_TEMP3      1252 /* Degrees Celsius * 10 */
 #define LM87_SYSCTL_FAN_DIV    2000 /* 1, 2, 4 or 8 */
 #define LM87_SYSCTL_ALARMS     2001 /* bitvector */
 #define LM87_SYSCTL_ANALOG_OUT 2002
@@ -291,12 +289,10 @@ static struct i2c_driver LM87_driver = {
 #define LM87_ALARM_FAN2         0x0080
 #define LM87_ALARM_IN4          0x0100
 #define LM87_ALARM_IN5          0x0200
-#define LM87_ALARM_RESERVED1    0x0400
-#define LM87_ALARM_RESERVED2    0x0800
 #define LM87_ALARM_CHAS         0x1000
 #define LM87_ALARM_THERM_SIG    0x2000
 #define LM87_ALARM_TEMP2_FAULT  0x4000
-#define LM87_ALARM_TEMP3_FAULT 0x08000
+#define LM87_ALARM_TEMP3_FAULT  0x8000
 
 /* -- SENSORS SYSCTL END -- */
 
@@ -426,8 +422,6 @@ static int lm87_detect(struct i2c_adapter *adapter, int address,
         client_name = "LM87 chip";
 	strcpy(new_client->name, client_name);
 	data->type = kind;
-
-	new_client->id = lm87_id++;
 	data->valid = 0;
 	init_MUTEX(&data->update_lock);
 
@@ -552,7 +546,7 @@ static void lm87_init_client(struct i2c_client *client)
 #endif
 	);
 
-	data->vrm = DEFAULT_VRM;
+	data->vrm = 82;
 
 	/* Start monitoring */
 	reg = lm87_read_value(client, LM87_REG_CONFIG);
